{% for method_name, item in methods.items %}

<div class="docs_panel panel {% if item.public %}panel-info{% elif item.private %}panel-danger{% elif item.protected %}panel-warning{% endif %} down">
    <div class="panel-heading">
        {{ item.text|escape }} ({% if item.public %}Доступен всем{% elif item.private %}{{ item.private }}{% elif item.protected %}Только по токену{% endif %})
        <i style="margin: 2px 0 0 0;" class="pull-right glyphicon glyphicon-chevron-down"></i>
    </div>
    <div class="panel-body">
        <p><strong>Url:</strong> <a target="_blank" href="{{ url }}">{{ url }}</a></p>
        <p><strong>Method:</strong> {{ method_name|upper }}</p>

        <br />
        <h4 style="margin: 0">Допустимые параметры:</h4>
        <table class="table table-striped table-hover">
            <thead>
                <tr>
                    <th>Параметр</th>
                    <th>Описание</th>
                    <th>Тип</th>
                    <th>Значение по умолчанию</th>
                </tr>
            </thead>
            <tbody>
                {% for field in item.fields %}
                     <tr>
                        <th>{{ field.name }}</th>
                        <td>{{ field.verbose_name }}</td>
                        <td>{{ field.type }}</td>
                        <td>{{ field.default }}</td>
                    </tr>
                {% endfor %}
            </tbody>
        </table>
    </div>
</div>

{% endfor %}